Package 'BiocPkgDash'

Title: An interactive Shiny dashboard for Bioconductor package maintainers
Description: This package provides an interactive Shiny dashboard for Bioconductor package maintainers. It visualizes various package statuses, metadata, and development metrics, offering insights into package health and activity. This tool aims to support maintainers of multiple packages by filtering packages via maintainer email.
Authors: Marcel Ramos [aut, cre] (ORCID: <https://orcid.org/0000-0002-3242-0582>), Vincent Carey [aut]
Maintainer: Marcel Ramos <[email protected]>
License: Artistic-2.0
Version: 1.1.0
Built: 2026-05-30 09:12:55 UTC
Source: https://github.com/bioc/BiocPkgDash

Help Index


The Bioconductor Package Dashboard

Description

A dashboard for Bioconductor package maintainers to monitor the status of their packages. The key input to the dashboard is the email the maintainer uses in their package's DESCRIPTION file. The dashboard displays the badge statuses of the package in both the release or devel branches of Bioconductor. The status is determined by the results of the Bioconductor nightly builds. The dashboard also provides a visualization of the status of the package checks on either the release or devel branches of Bioconductor.

Usage

BiocPkgDash(email = NULL, ...)

Arguments

email

character(1) vector providing the email of the maintainer. By default, the package will look for the email in the URL query.

...

Additional parameters to pass to the shiny::shinyApp() function.

Value

called for the side effect of initializing a shiny app

Examples

BiocPkgDash()

A Summary Plot for Package Statuses

Description

This function generates a stacked bar plot of package statuses for a given Bioconductor version and email combination. It is mainly used for the Bioconductor Package Dashboard.

Usage

pkgStatusPlot(
  data = NULL,
  status = c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped"),
  stage = c("install", "buildsrc", "checksrc", "buildbin")
)

Arguments

data

tibble() / data.frame() A data frame of maintained packages. This is used internally to avoid repeated calls to the BiocPkgTools::biocMaintained() function.

status

character() A vector of INSTALL, build and check statuses to include in the plot. These values are obtained from the result column in BiocPkgTools::biocBuildReport(). The default is all: c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped").

stage

character() A vector of the Bioconductor Build System (BBS) stages to include in the plot. These values are obtained from the stage BiocPkgTools::biocBuildReport(). The default is all stages: c("install", "buildsrc", "checksrc", "buildbin").

Details

Note that binary build stages for the Linux builders are not included in the plot. This is because the binaries are built on GitHub Actions and their result are not included in the Bioconductor Build System (BBS) database.

Value

An interactive ggplotly object.

Examples

data <- BiocPkgTools::biocMaintained(
    "[email protected]", pkgType = "software"
)
pkgStatusPlot(data)

Build a table of package build statuses

Description

This function builds a table of package build statuses for a given Bioconductor version and email combination. It is mainly used for the Bioconductor Package Dashboard.

Usage

pkgStatusTable(
  data = NULL,
  status = c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped"),
  stage = c("install", "buildsrc", "checksrc", "buildbin")
)

Arguments

data

tibble() / data.frame() A table of maintained packages. This is used internally to avoid repeated calls to the BiocPkgTools::biocMaintained() function.

status

character() The status of the builders to include in the table. These values are obtained from the result column in BiocPkgTools::biocBuildReport(). The default is all: c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped").

stage

character() A vector of the Bioconductor Build System (BBS) stages to include in the plot. These values are obtained from the stage BiocPkgTools::biocBuildReport(). The default is all stages: c("install", "buildsrc", "checksrc", "buildbin").

Details

Note that binary build stages for the Linux builders are marked as skipped in the table. This is because the binaries are built on GitHub Actions and their result are not included in the Bioconductor Build System (BBS) database. Provide the data argument to avoid recomputing the list of maintained packages for a given email and Bioconductor version. Annotation packages are not included in the table because they are not built regularly by the BBS.

Value

A tibble() / data.frame() with the package build statuses for the given data input.

Examples

data <- BiocPkgTools::biocMaintained("[email protected]")
pkgStatusTable(data)