| Title: | An interactive Shiny dashboard for Bioconductor package maintainers |
|---|---|
| Description: | This package provides an interactive Shiny dashboard for Bioconductor package maintainers. It visualizes various package statuses, metadata, and development metrics, offering insights into package health and activity. This tool aims to support maintainers of multiple packages by filtering packages via maintainer email. |
| Authors: | Marcel Ramos [aut, cre] (ORCID: <https://orcid.org/0000-0002-3242-0582>), Vincent Carey [aut] |
| Maintainer: | Marcel Ramos <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.1.0 |
| Built: | 2026-05-30 09:12:55 UTC |
| Source: | https://github.com/bioc/BiocPkgDash |
A dashboard for Bioconductor package maintainers to monitor the
status of their packages. The key input to the dashboard is the email the
maintainer uses in their package's DESCRIPTION file. The dashboard
displays the badge statuses of the package in both the release or devel
branches of Bioconductor. The status is determined by the results of the
Bioconductor nightly builds. The dashboard also provides a visualization of
the status of the package checks on either the release or devel
branches of Bioconductor.
BiocPkgDash(email = NULL, ...)BiocPkgDash(email = NULL, ...)
email |
|
... |
Additional parameters to pass to the |
called for the side effect of initializing a shiny app
BiocPkgDash()BiocPkgDash()
This function generates a stacked bar plot of package statuses for a given Bioconductor version and email combination. It is mainly used for the Bioconductor Package Dashboard.
pkgStatusPlot( data = NULL, status = c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped"), stage = c("install", "buildsrc", "checksrc", "buildbin") )pkgStatusPlot( data = NULL, status = c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped"), stage = c("install", "buildsrc", "checksrc", "buildbin") )
data |
|
status |
|
stage |
|
Note that binary build stages for the Linux builders are not included in the plot. This is because the binaries are built on GitHub Actions and their result are not included in the Bioconductor Build System (BBS) database.
An interactive ggplotly object.
data <- BiocPkgTools::biocMaintained( "[email protected]", pkgType = "software" ) pkgStatusPlot(data)data <- BiocPkgTools::biocMaintained( "[email protected]", pkgType = "software" ) pkgStatusPlot(data)
This function builds a table of package build statuses for a given Bioconductor version and email combination. It is mainly used for the Bioconductor Package Dashboard.
pkgStatusTable( data = NULL, status = c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped"), stage = c("install", "buildsrc", "checksrc", "buildbin") )pkgStatusTable( data = NULL, status = c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped"), stage = c("install", "buildsrc", "checksrc", "buildbin") )
data |
|
status |
|
stage |
|
Note that binary build stages for the Linux builders are marked as
skipped in the table. This is because the binaries are built on GitHub
Actions and their result are not included in the Bioconductor Build System
(BBS) database. Provide the data argument to avoid recomputing the
list of maintained packages for a given email and Bioconductor version.
Annotation packages are not included in the table because they are not
built regularly by the BBS.
A tibble() / data.frame() with the package build statuses for
the given data input.
data <- BiocPkgTools::biocMaintained("[email protected]") pkgStatusTable(data)data <- BiocPkgTools::biocMaintained("[email protected]") pkgStatusTable(data)